@@ -165,7 +165,8 @@ def eql(text, text1):
 # Contributed by Stjujsckij Nickolaj
 def enconvert(text, enc_name):
     ''' Convert from non-standard encoding, "Convert to encoding: $0, Encoding: $1"
-&Encoding, combo, cp1250, cp1251, cp1252, cp1253, cp1254, cp1255, cp1256, cp1257, cp1258'''
+&Encoding, combo, cp1250, cp1251, cp1252, cp1253, cp1254, cp1255, cp1256, cp1257, cp1258,\
+euc_jp, cp932, euc_jis_2004, shift_jis, johab, big5, big5hkscs, gb2312, gb18030, gbk, hz'''
     return text.encode("latin1", 'replace').decode(enc_name, 'replace')
 
 def filenametotag(m_tags, p_pattern):
@@ -1051,9 +1052,9 @@ functions = {
     'to_num': to_num
 }
 
-no_fields = (filenametotag, load_images, move, remove_except,
-    save_artwork, tag_dir, update_from_tag)
-no_preview = (autonumbering, load_images, remove_tag, save_artwork)
+no_fields = [filenametotag, load_images, move, remove_except,
+    save_artwork, tag_dir, update_from_tag]
+no_preview = [autonumbering, load_images, remove_tag, save_artwork]
 
 import findfunc
 FuncError = findfunc.FuncError
